@@ -1,4 +1,6 @@
 from django import template
+from django.forms import CheckboxInput
+
 
 register = template.Library()
 
@@ -14,4 +16,9 @@ def titlify(field):
         field = field.split("__")[0]
     elif field.lower() == 'id':
         return 'ID'
-    return field.replace('_', ' ').title()
\ No newline at end of file
+    return field.replace('_', ' ').title()
+
+
+@register.filter(name='get_field_type')
+def get_field_type(field):
+    return field.field.widget.__class__.__name__
\ No newline at end of file
